package com.yijia.customer.service.impl;

import java.util.List;
import com.yijia.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yijia.customer.mapper.CustomerCardUseRecordMapper;
import com.yijia.customer.domain.CustomerCardUseRecord;
import com.yijia.customer.service.ICustomerCardUseRecordService;

/**
 * 客户电子会员卡充值消费记录Service业务层处理
 *
 * @author yijia
 * @date 2021-05-18
 */
@Service
public class CustomerCardUseRecordServiceImpl implements ICustomerCardUseRecordService
{
    @Autowired
    private CustomerCardUseRecordMapper customerCardUseRecordMapper;

    /**
     * 查询客户电子会员卡充值消费记录
     *
     * @param id 客户电子会员卡充值消费记录ID
     * @return 客户电子会员卡充值消费记录
     */
    @Override
    public CustomerCardUseRecord selectCustomerCardUseRecordById(Long id)
    {
        return customerCardUseRecordMapper.selectCustomerCardUseRecordById(id);
    }

    /**
     * 查询客户电子会员卡充值消费记录列表
     *
     * @param customerCardUseRecord 客户电子会员卡充值消费记录
     * @return 客户电子会员卡充值消费记录
     */
    @Override
    public List<CustomerCardUseRecord> selectCustomerCardUseRecordList(CustomerCardUseRecord customerCardUseRecord)
    {
        return customerCardUseRecordMapper.selectCustomerCardUseRecordList(customerCardUseRecord);
    }

    /**
     * 新增客户电子会员卡充值消费记录
     *
     * @param customerCardUseRecord 客户电子会员卡充值消费记录
     * @return 结果
     */
    @Override
    public int insertCustomerCardUseRecord(CustomerCardUseRecord customerCardUseRecord)
    {
        customerCardUseRecord.setCreateTime(DateUtils.getNowDate());
        return customerCardUseRecordMapper.insertCustomerCardUseRecord(customerCardUseRecord);
    }

    /**
     * 修改客户电子会员卡充值消费记录
     *
     * @param customerCardUseRecord 客户电子会员卡充值消费记录
     * @return 结果
     */
    @Override
    public int updateCustomerCardUseRecord(CustomerCardUseRecord customerCardUseRecord)
    {
        return customerCardUseRecordMapper.updateCustomerCardUseRecord(customerCardUseRecord);
    }

    /**
     * 批量删除客户电子会员卡充值消费记录
     *
     * @param ids 需要删除的客户电子会员卡充值消费记录ID
     * @return 结果
     */
    @Override
    public int deleteCustomerCardUseRecordByIds(Long[] ids)
    {
        return customerCardUseRecordMapper.deleteCustomerCardUseRecordByIds(ids);
    }

    /**
     * 删除客户电子会员卡充值消费记录信息
     *
     * @param id 客户电子会员卡充值消费记录ID
     * @return 结果
     */
    @Override
    public int deleteCustomerCardUseRecordById(Long id)
    {
        return customerCardUseRecordMapper.deleteCustomerCardUseRecordById(id);
    }

    /*充值消费汇总
     */
    @Override
    public CustomerCardUseRecord listCZXFData(CustomerCardUseRecord customerCardUseRecord) {
        return customerCardUseRecordMapper.listCZXFData(customerCardUseRecord);
    }
}
